# This is a slightly overly-clever example of using
# VtSetValues and VtGetValues to manipulate Scales
# and Text widgets.

proc QuitCB {cbs} {
    VtClose; exit 0
}

proc UpdateTextValues {form} {
	global horizontalScaleW verticalScaleW 

	set value [VtGetValues $horizontalScaleW -value]
	set min   [VtGetValues $horizontalScaleW -min]
	set max   [VtGetValues $horizontalScaleW -max]

	VtSetValues $form.minTextW -value $min
	VtSetValues $form.maxTextW -value $max
	VtSetValues $form.valueTextW -value $value
}


proc SetSelectedScaleResourceCB {option cbs} {
	global horizontalScaleW verticalScaleW

	switch $option {
		"value" {
			set widgetValue [keylget cbs value]
			VtSetValues $horizontalScaleW -value $widgetValue
			VtSetValues $verticalScaleW -value $widgetValue
		}
		"min" {
			set widgetValue [keylget cbs value]
			VtSetValues $horizontalScaleW -min $widgetValue
			VtSetValues $verticalScaleW -min $widgetValue
		}
		"max" {
			set widgetValue [keylget cbs value]
			VtSetValues $horizontalScaleW -max $widgetValue
			VtSetValues $verticalScaleW -max $widgetValue
		}
		"title" {
			set widgetValue [keylget cbs value]
			VtSetValues $horizontalScaleW -title $widgetValue
			VtSetValues $verticalScaleW -title $widgetValue
		}
		"showValue" {
			#
        		#toggle button uses "set" not "value"
			#
			set widgetValue [keylget cbs set]
			VtSetValues $horizontalScaleW -showValue $widgetValue
			VtSetValues $verticalScaleW -showValue $widgetValue
		}
	}
}

proc UpdateScaleValueCB {cbs} {
	SetSelectedScaleResourceCB "value" $cbs
	set form [keylget cbs dialog]
	UpdateTextValues $form
}

#
# Start Program
#
set app [VtOpen scales]

set mainForm [VtFormDialog $app.form \
	-title "Scales" \
	-okCallback QuitCB \
	]

set horizontalScaleW [VtScale $mainForm.scale_horz \
	-callback UpdateScaleValueCB \
	-horizontal \
	-min 10 \
	-max 100 \
	-value 50 \
	-topSide FORM \
	-leftSide FORM \
	]

set verticalScaleW [VtScale $mainForm.scale_vert \
	-callback UpdateScaleValueCB \
	-vertical \
	-min 10 \
	-max 100 \
	-value 50 \
	-leftSide FORM \
	-topOffset 20 \
	-CHARM_topOffset 0 \
	-topSide $horizontalScaleW \
	]

set titleLabelW [VtLabel $mainForm.titleLabelW \
	-label "Enter Title:" \
	-topSide FORM \
	-leftSide $horizontalScaleW \
	-leftOffset 60  \
	-topOffset  10  \
	-CHARM_topOffset 0 \
	-CHARM_leftOffset 7 \
	]

set titleTextW [VtText $mainForm.titleTextW \
	-callback "SetSelectedScaleResourceCB title" \
	-columns 15 \
	-topSide FORM  \
	-leftSide $titleLabelW \
	-rightSide FORM \
	-topOffset  10  \
	-CHARM_topOffset 0 \
	]

set valueLabelW [VtLabel $mainForm.valueLabelW \
	-label "Value:" \
	-rightSide $titleTextW\
	-leftSide $horizontalScaleW \
	-topSide $mainForm.titleTextW  \
	-labelRight \
	]

set valueTextW [VtText $mainForm.valueTextW \
	-callback "SetSelectedScaleResourceCB value" \
	-columns 3 \
	-leftSide $valueLabelW \
	-topSide $titleTextW]

set minLabelW [VtLabel $mainForm.minLabelW \
	-label "Min:" \
	-leftSide $horizontalScaleW \
	-rightSide $valueTextW \
	-topSide $valueTextW \
	-labelRight \
	]

set minTextW [VtText $mainForm.minTextW \
	-callback "SetSelectedScaleResourceCB min" \
	-columns 3 \
	-leftSide $minLabelW \
	-topSide $valueTextW \
	]

set maxLabelW [VtLabel $mainForm.maxLabelW \
	-label "Max:" \
	-leftSide $horizontalScaleW \
	-rightSide $minTextW \
	-topSide $minTextW \
	-labelRight \
	]

set maxTextW [VtText $mainForm.maxTextW \
	-callback "SetSelectedScaleResourceCB max" \
	-columns 3 \
        -leftSide $maxLabelW \
	-topSide $minTextW \
	]


set showValue [VtToggleButton $mainForm.showValue \
	-label "Show Scale Value" \
	-value 1 \
	-callback "SetSelectedScaleResourceCB showValue" \
	-topSide $maxTextW \
	-leftSide $maxLabelW \
	-CHARM_topOffset 1 \
	]

UpdateTextValues $mainForm

VtShow $mainForm
VtMainLoop

